@@ -134,7 +134,8 @@ def decodeSetGovVariable(hex,withHeight):
                     {'bytesCount': 1, 'key': 'typeId', 'type': int,'endian':None},
                     {'bytesCount': 4, 'key': 'key', 'type': str,'endian':'big'},
                     {'bytesCount': 4, 'key': 'keyId', 'type': int,'endian':'little'},
-                    {'bytesCount': 'rest', 'key': 'value', 'type': int,'endian':'little'}
+                    {'bytesCount': 4, 'key': 'minuend', 'type': int,'endian':'little'},
+                    {'bytesCount': 4, 'key': 'subtractive', 'type': int,'endian':'little'}
                 ]
                 result['attributes'].append(searchHex(variables,hex[8:44]))
                 hex = hex[44:]
@@ -165,7 +166,8 @@ def decodeSetGovVariable(hex,withHeight):
                     {'bytesCount': 4, 'key': 'tokenId', 'type': int,'endian':'little'},
                     {'bytesCount': 1, 'key': 'key', 'type': str,'endian':None},
                     {'bytesCount': 4, 'key': 'keyId', 'type': int,'endian':'little'},
-                    {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+                    {'bytesCount': 4, 'key': 'minuend', 'type': int,'endian':'little'},
+                    {'bytesCount': 4, 'key': 'subtractive', 'type': int,'endian':'little'}
                 ]
                 result['attributes'].append(searchHex(variables,hex[8:44]))
                 hex = hex[44:]
