@@ -95,19 +95,19 @@ def addPoolLiquidity(amountA,amountB,reserveA,reserveB,totalLiquidity):
     # No Checks included! Only useable for valid block transactions!
     # https://github.com/DeFiCh/ain/blob/a7d914f15f762d121ac2c5d07d38d30cf7e09d4d/src/masternodes/poolpairs.cpp
     if totalLiquidity == 0:
-        liq = ArithUint256(amountA) * amountB
-        liquidity = int(math.floor(math.sqrt(liq.low64)))
+        liq = amountA * amountB
+        liquidity = int(math.floor(math.sqrt(liq)))
         if liquidity < MINIMUM_LIQUIDITY:
             return 0
         else:
             return liquidity - MINIMUM_LIQUIDITY
     
-    totalLiquidity = totalLiquidity + MINIMUM_LIQUIDITY
+    #totalLiquidity = totalLiquidity + MINIMUM_LIQUIDITY
     
-    liqA = ArithUint256(amountA) * totalLiquidity / reserveA
-    liqB = ArithUint256(amountB) * totalLiquidity / reserveB
+    liqA = int(amountA * totalLiquidity / reserveA)
+    liqB = int(amountB * totalLiquidity / reserveB)
 
-    return min(liqA.low64, liqB.low64)
+    return min(liqA, liqB)
 
 def addPoolLiquidityOptimiser():
     # TODO: build opitimiser
@@ -125,10 +125,10 @@ def addPoolLiquidityOptimiser():
 def removePoolLiquidity(liquidity,reserveA,reserveB,totalLiquidity):
     # No Checks included! Only useable for valid block transactions!
     # https://github.com/DeFiCh/ain/blob/a7d914f15f762d121ac2c5d07d38d30cf7e09d4d/src/masternodes/poolpairs.cpp
-    amountA = ArithUint256(liquidity) * reserveA / totalLiquidity
-    amountB =  ArithUint256(liquidity) * reserveB / totalLiquidity
+    amountA = int(liquidity * reserveA / totalLiquidity)
+    amountB =  int(liquidity * reserveB / totalLiquidity)
 
-    return amountA.low64,amountB.low64
+    return amountA,amountB
 
 def poolSwap(block,fromAmount,isForward,reserveA,reserveB,commission=0,dexfeeInPct=0,dexfeeOutPct=0):
     # No Checks included! Only useable for valid block transactions!
@@ -166,7 +166,7 @@ def poolSwap(block,fromAmount,isForward,reserveA,reserveB,commission=0,dexfeeInP
     if block < BAY_FRONT_GARDENS_HEIGHT:
         while unswapped > 0:
             stepFrom = min(chunk,unswapped)
-            stepTo = poolTo * stepFrom / poolFrom
+            stepTo = int(poolTo * stepFrom / poolFrom)
             poolFrom = poolFrom + stepFrom
             poolTo = poolTo - stepTo
             unswapped = unswapped - stepFrom
@@ -193,22 +193,22 @@ def poolSwap(block,fromAmount,isForward,reserveA,reserveB,commission=0,dexfeeInP
         reserveAChange = poolTo - reserveT 
     return int(reserveAChange),int(reserveBChange),int(swapped),int(tradeFee),int(dexfeeInAmount),int(dexfeeOutAmount)
 
-# TEST FIRST FOUR DAX-DUSD TX
+#TEST FIRST FOUR DAX-DUSD TX
 # if __name__ == '__main__':
-# #     amountA = 20000000
-# #     amountB = 456000000
+# #     amountA = 1000000000
+# #     amountB = 1245000000000
 # #     reserveA = 0
 # #     reserveB = 0
 # #     totalLiq = 0
 # #     i = addPoolLiquidity(amountA,amountB,reserveA,reserveB,totalLiq)
 # #     print(i)
 
-#     reserveA = 100000000
-#     reserveB = 4066700000000
+#     reserveA = 444500000000
+#     reserveB = 200000000000
 #     totalLiq = 917403152
-#     amountA = 900000000
+#     amountA = 3500000000
     
-#     AChange,BChange,swapped,commission,dexIn,dexOut = poolSwap(480000,amountA,False,reserveA,reserveB,0.002,0.001,0.001)
+#     AChange,BChange,swapped,commission,dexIn,dexOut = poolSwap(480000,amountA,True,reserveA,reserveB,0.002,0,0)
 #     print(swapped)
 #     reserveA = poolT + 1 #correction
 #     reserveB = poolF
